@@ -1,5 +1,6 @@
 from flask_discord_interactions.models.channel import Channel, ChannelType
 from flask_discord_interactions.models.user import User, Member
+from flask_discord_interactions.models.attachment import Attachment
 from flask_discord_interactions.models.message import Message, ResponseType
 from flask_discord_interactions.models.embed import Embed
 from flask_discord_interactions.models.component import (
@@ -50,4 +51,5 @@ __all__ = [
     "Autocomplete",
     "AutocompleteResult",
     "Option",
+    "Attachment",
 ]
